@@ -1,13 +1,13 @@
 #/usr/bin/env python
-import sys
 from optparse import Option, OptionParser, BadOptionError
 import hashlib
+import logging
 import os
-import string
 import re
+import string
+import sys
 import types
 import urllib
-import logging
 
 
 logging.basicConfig(loglevel=logging.INFO)
@@ -18,13 +18,8 @@ try:
 except ImportError:
     from cgi import parse_qsl
 
-try:
-    next
-except NameError:
-    next = lambda x: x.next()
 
-
-__version__ = '0.2.3'
+__version__ = '0.2.4'
 BACKENDS = {
     'postgresql': 'django.db.backends.postgresql_psycopg2',
     'mysql': 'django.db.backends.mysql',
@@ -187,7 +182,11 @@ def make_secret_key(options):
 
 
 def main(argv):
-    from django.core.management import execute_from_command_line
+    try:
+        from django.core.management import execute_from_command_line
+    except ImportError, err:
+        sys.stderr.write('%s.\nIs Django installed?\n' % str(err))
+        sys.exit(1)
 
     options, django_options, arguments = parse_args(argv[1:])
     settings = dict(DJANGO_SETTINGS)
